Class: MediaProcessingTool::XMLParser

Inherits:
Object
  • Object
show all
Defined in:
lib/media_processing_tool/xml_parser.rb,
lib/media_processing_tool/xml_parser/document.rb,
lib/media_processing_tool/xml_parser/identifier.rb

Defined Under Namespace

Classes: Document, Identifier

Class Method Summary collapse

Class Method Details

.identifier_documentObject

Gives access to the last document returned by the Identifier This gives access to the identifiers instance parameters (such determined type) for use later



10
11
12
# File 'lib/media_processing_tool/xml_parser.rb', line 10

def self.identifier_document
  @identifier_document
end

.parse(xml, args = { }) ⇒ Object

self.identifier_document



14
15
16
17
18
19
20
21
22
23
24
25
26
# File 'lib/media_processing_tool/xml_parser.rb', line 14

def self.parse(xml, args = { })
  @identifier_document = Identifier.load(xml, args)

  case @identifier_document.type
  when :final_cut_pro
    doc = FinalCutPro::XMLParser.parse(@identifier_document.xml_document, args)
  when :itunes
    doc = ITunes::XMLParser.parse(xml, args)
  else
    doc = @identifier_document
  end
  doc
end